MethodChannelSfmcPlugin class

An implementation of SfmcPluginPlatform that uses method channels.

Inheritance

Constructors

MethodChannelSfmcPlugin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTag(String? tag) → Future<bool?>
To Add Tags
override
clearProfileAttribute(String key) → Future<bool?>
Clear Profile Attribute @param key - Key of the attribute
override
getContactKey() → Future<String?>
To Get Contact Key
override
getTags() → Future<List<String>>
To Get Tags
override
initialize({String? appId, String? accessToken, String? mid, String? sfmcURL, String? senderId, bool? delayRegistration, bool? analytics}) → Future<bool?>
To Initialize the SDK for iOS only
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTag(String? tag) → Future<bool?>
To Remove Tags
override
setContactKey(String? contactKey) → Future<bool?>
To Set Contact Key
override
setHandler(Future handler(MethodCall call)?) → dynamic
(Applicable to iOS only - pass URL to Flutter through 'handle_url' methodCall.method - refer to example)
override
setProfileAttribute(String key, String value) → Future<bool?>
Set Profile Attribute @param key - Key of the attribute @param value - Value of the attribute
override
setPushEnabled(bool? enabled) → Future<bool?>
To Enable/Disable Push Notification
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited