SfmcPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SfmcPluginPlatform
Implementers

Constructors

SfmcPluginPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTag(String? tag) → Future<bool?>
To Add Tags
clearProfileAttribute(String key) → Future<bool?>
Clear Profile Attribute @param key - Key of the attribute
getContactKey() → Future<String?>
To Get Contact Key
getTags() → Future<List<String>>
To Get Tags
initialize({String? appId, String? accessToken, String? mid, String? sfmcURL, String? senderId, bool? delayRegistration, bool? analytics}) → Future<bool?>
To Initialize the SDK for iOS only
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTag(String? tag) → Future<bool?>
To Remove Tags
setContactKey(String? contactKey) → Future<bool?>
To Set Contact Key
setHandler(Future handler(MethodCall call)?) → dynamic
(Applicable to iOS only - pass URL to Flutter through 'handle_url' methodCall.method - refer to example)
setProfileAttribute(String key, String value) → Future<bool?>
Set Profile Attribute @param key - Key of the attribute @param value - Value of the attribute
setPushEnabled(bool? enabled) → Future<bool?>
To Enable/Disable Push Notification
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ SfmcPluginPlatform
getter/setter pair